function [x y] = corrdim(X, mindist)
% [x y] = corrdim(X, mindist)
% calculates correlational dimension of the set in n-dimensional space
%
% INPUT:  X           a set in n-dimensional space (size(X, 2)=n)
%         mindist     minimal distance
%
% OUTPUT: [x y]       points
%                     x - epsilon
%                     y - propability that distance between 2 points will be
%                     less than epsilon
%
% (c) Ruslan Enikeev http://profitengines.ru

if nargin < 2
	error(['At least two input arguments are required. Please type ' ...
	       '''help corrdim'' for usage information.']);
end

N = size(X,1);          %number of points
dimcnt = size(X, 2);    %dimension

bins = mindist(1,1);
maxdist = norm(max(X) - min(X));

while bins(end)<=maxdist
    bins(end+1) = bins(end)*2;
end

np = interbin(X', bins);
x = log2(bins);

nbins = size(np,1);
for i=1:nbins
    y(i) = sum(np(1:i))/N/(N-1);
end

x(y==0) = [];
y(y==0) = [];

y = log2(y);

