function coordmat = sierpinski(height, plotflag)

% coordmat = sierpinski(HEIGHT, plotflag)
% Draw the Sierpinski gasket of height HEIGHT.
% Uses the Pascal triangle analogy to assemble the structure.
%    Example:
%       sierpinski(64);
% returns the coordinates of the sierpinski set in coordmat
% For whole biggest triangle use height 2, 4, 8, 16, .., 2^n

if nargin < 1
    error(['At least one input arguments are required. Please type ' ...
        '''help sierpinski'' for usage information.']);
end

if nargin < 2
    plotflag = 0;
end

coordvec = [];
for y=0:height-1
    for x=0:y
        if bitand(x,(y-x)) == 0
            coordvec(end+1) = x+height-.5*y;
            coordvec(end+1) = height/2-(y);
        end
    end
end
coordmat = zeros(length(coordvec)/2,2);
coordmat(:,1) = coordvec(1:2:end);
coordmat(:,2) = coordvec(2:2:end);

if plotflag == 1
    hold on;
    plot(coordmat(:,1), coordmat(:,2),'r.');
    axis equal; axis off;
    set(gca,'FontSize',14);
    set(gcf,'Color',[1,1,1]);
    title('The Sierpinski Gasket');
    hold off;
end